@@ -18,7 +18,9 @@ import fnmatch
 
 
 def get_soname(libfile: str) -> str:
-    """Helper: get soname from library"""
+    """Helper: get soname from library
+    shared libs in Debian _should_ have a SONAME, SOVER
+    """
     res = check_output(["objdump", "-p", libfile]).decode("utf-8")
     for line in res.split("\n"):
         lk = line.split()
@@ -30,6 +32,7 @@ def get_soname(libfile: str) -> str:
                 # Format libxxx-2.0.0.so
                 major = ""
             return (major, soname, ext)
+    return None
 
 
 ##
