@@ -15,7 +15,6 @@ import dhfortran.targets as targets
 @click.group()
 @click.pass_context
 def dh_fortran(ctx):
-    cli.verbose_print("dh_fortran called")
     # breakpoint()    # ensure that ctx.obj exists and is a dict
     # (in case `cli()` is called by means other than the `if` block below)
     ctx.ensure_object(dict)
@@ -28,11 +27,11 @@ def get_fc_flags(fc):
     """
     Returns set of flags to be set , either passed as FCFLAGS to another
     """
-    cli.verbose_print("dh_fortran get_fc_flags called")
     if fc is None:
         fc = cmplrs.get_fc_default()
     cli.validate_compiler(fc)
-    click.echo(cmplrs.get_fc_flags(fc))
+    flavor,arch = cmplrs.get_fc_flavor_arch(fc)
+    click.echo(cmplrs.get_fc_flags(flavor,arch))
 
 
 @dh_fortran.command("get_f77_flags")
@@ -41,7 +40,6 @@ def get_f77_flags(f77):
     """
     Returns flags for a FORTRAN 77 compiler (recommended contents of FFLAGS)
     """
-    cli.verbose_print("dh_fortran get_f77_flags called")
     cli.validate_compiler(f77)
     click.echo(cmplrs.get_f77_flags(f77))
 
@@ -53,7 +51,6 @@ def get_ld_flags(fc):
     """
     Returns set of flags to be set , either passed as FCFLAGS to another
     """
-    cli.verbose_print("dh_fortran get_ld_flags called")
     cli.validate_compiler(fc)
     flavor, arch = cmplrs.get_fc_flavor_arch(fc)
     click.echo(cmplrs.get_ld_flags(flavor, arch))
@@ -66,7 +63,6 @@ def get_fc_default(ctx, fc):
     """
     Details on get_fc_default
     """
-    cli.verbose_print("dh_fortran get_fc_default called")
     cli.validate_compiler(fc)
     click.echo(cmplrs.get_fc_default(fc))
 
@@ -75,7 +71,6 @@ def get_fc_default(ctx, fc):
 @click.option("--fc", default=None, help="Fortran compiler")
 @click.pass_context
 def get_fc_optional(ctx, fc):
-    cli.verbose_print("dh_fortran get_fc_optional called")
     cli.validate_compiler(fc)
     flavor, arch = cmplrs.get_fc_flavor_arch(fc)
     click.echo(" ".join(cmplrs.get_fc_optional(flavor)))
@@ -92,7 +87,6 @@ def get_fc_optional(ctx, fc):
     default=False,
 )
 def get_flibdir(ctx, fc, prepend):
-    cli.verbose_print("dh_fortran get_flibdir called")
     cli.validate_compiler(fc)
     flavor, arch = cmplrs.get_fc_flavor_arch(fc)
     prefix = "-L" if prepend else ""
@@ -112,7 +106,6 @@ def get_flibdir(ctx, fc, prepend):
     default=False,
 )
 def get_flibdirs(ctx, fc, prepend):
-    cli.verbose_print("dh_fortran get_flibdirs called")
     cli.validate_compiler(fc)
     flavor, arch = cmplrs.get_fc_flavor_arch(fc)
     libdirs = cmplrs.get_flibdirs(flavor, arch)
@@ -133,7 +126,6 @@ def get_flibdirs(ctx, fc, prepend):
 )
 @click.pass_context
 def get_fmoddir(ctx, flavor, fc, prepend):
-    cli.verbose_print("dh_fortran get_fmoddir called")
     cli.validate_compiler(fc)
     flavor, arch = cmplrs.get_fc_flavor_arch(flavor if fc is None else fc)
     # May be "-I" or "-module " depending on compiler
@@ -160,7 +152,6 @@ def get_fmoddir(ctx, flavor, fc, prepend):
 )
 @click.pass_context
 def get_fmoddirs(ctx, fc, prepend):
-    cli.verbose_print("dh_fortran get_fmoddirs called")
     cli.validate_compiler(fc)
     flavor, arch = cmplrs.get_fc_flavor_arch(fc)
     # TODO. May be "-I" or "-M" depending on compiler
@@ -183,7 +174,6 @@ def get_fmoddirs(ctx, fc, prepend):
 @click.option("--flavor", help="Fortran flavor (eg gfortran-15, flang-21)")
 @click.pass_context
 def get_fc_exe(ctx, flavor):
-    cli.verbose_print("dh_fortran get_fc_exe called")
     cli.validate_flavor(flavor)
     click.echo(cmplrs.get_fc_exe(flavor))
 
@@ -192,7 +182,6 @@ def get_fc_exe(ctx, flavor):
 @click.option("--fc", help="Fortran compiler  (eg gfortran-15, flang-21)")
 @click.pass_context
 def get_abi_vendor(ctx, fc):
-    cli.verbose_print("dh_fortran get_abi_vendor called")
     cli.validate_compiler(fc)
     flavor, arch = cmplrs.get_fc_flavor_arch(fc)
     click.echo(cmplrs.get_abi_vendor(flavor))
@@ -205,7 +194,6 @@ def get_abi_vendor(ctx, fc):
 @click.option("--fc", default=None, help="Fortran compiler")
 @click.option("--save", default=False, is_flag=True, hidden=True)
 def get_env(fc: str, save: bool):
-    cli.debug_print("dh_fortran get_env called")
     cli.validate_compiler(fc)
     flavor, arch = cmplrs.get_fc_flavor_arch(fc)
     if save:
