@@ -30,11 +30,12 @@ class PkgconfFileHelper(dh.DhFortranHelper):
         return False
 
     def compute_dest(self, src_file, vendor=None, flavor=None):
-        """Where does pkgconfig file go ? Should be called by base DebHelper() to move files"""
+        """Where does pkgconfig file go ? 
+        Should be called by base DebHelper() to move files"""
 
     def process_file(self, pkg, filename, target_pkg, target_dest=None):
         cli.debug_print(
-            f"process_file [pkgconf]  name {filename} target_pkg {target_pkg} target_dest {target_dest}"
+            f"process_file [pkgconf]  {filename=} {target_pkg=} {target_dest=}"
         )
         fmoddir = cmplrs.get_fmoddir(self.options.flavor, self.options.arch)
         flibdir = cmplrs.get_flibdir(self.options.flavor, self.options.arch)
@@ -89,26 +90,28 @@ def dh_fortran_pkgconf(files, *args, **kwargs):
     and libraries for a given compiler.
 
     *dh_fortran_pkgconf* is expected to be automatically added using the debhelper
-    "addon" <fortran> ie. either automatically, by build-depending on 'dh-sequence-fortran',
-    or explicitly:
+    "addon" <fortran> ie. either automatically, by build-depending on 
+    'dh-sequence-fortran', or explicitly:
 
         dh $@ --with fortran
 
-    <dh_fortran_pkgconf> Searches the debian/ directory for files B<debian/pkg.fortran-pkgconf>
-    which lists pkgconfig files to process, with the same syntax as debhelper install files.
+    <dh_fortran_pkgconf> Searches the debian/ directory for files 
+    B<debian/pkg.fortran-pkgconf> which lists pkgconfig files to process, 
+    with the same syntax as debhelper install files.
 
     OPTIONS
         --tmpdir=dir
         --sourcedir=dir
 
-    Look in the specified directory for files to be installed. It will look in tmpdir first
-    (typically debian/tmp) then sourceddir (.).
+    Look in the specified directory for files to be installed. It will look in 
+    tmpdir first (typically debian/tmp) then sourceddir (.).
 
     USAGE
 
-    The source pkgconfig file will be read and any placeholders @FMODDIR@, @FLIBDIR@ and @FC@
-    will be updated to the correct values. If these are not found, relevant lines in the
-    value section will be updated (eg. fmoddir= lines).
+    The source pkgconfig file will be read and any placeholders @FMODDIR@, 
+    @FLIBDIR@ and @FC@ will be updated to the correct values. 
+    If these are not found, relevant lines in the value section will be 
+    updated (eg. fmoddir= lines).
 
     TODO
 
@@ -116,11 +119,14 @@ def dh_fortran_pkgconf(files, *args, **kwargs):
     (2) Insert fmoddir, flibdir if missing
 
 
-    The fortran-pkgconf file syntax follows dh_install: pairs of sources and optional target directories.
-    If the target directory is absolute (starts with a  '/'), this directory is used in the target package.
-    If the target  does not absolute, it will be treated as a subdirectory of the pkgconfig path.
+    The fortran-pkgconf file syntax follows dh_install: pairs of sources 
+    and optional target directories. If the target directory is absolute 
+    (starts with a  '/'), this directory is used in the target package.
+    If the target  does not absolute, it will be treated as a subdirectory 
+    of the pkgconfig path.
 
-    The rewritten pkgconfig files will by default be added to /usr/lib/$multiarch/fortran/$compiler-flavor/pkgconfig
+    The rewritten pkgconfig files will by default be added to 
+          /usr/lib/$multiarch/fortran/$compiler-flavor/pkgconfig
     (eg usr/lib/aarch64-linux-gnu/fortran/gfortran-15/pkgconfig/mypkg.pc )
     This can then be used in the PKG_CONFIG_PATH
     """
